@@ -5,10 +5,11 @@ class Page:
     def __init__(self, integrations_token, database_id):
         self.url = 'https://api.notion.com/v1/pages'
         self.result = {}
-        self.request = Request(self.url, integrations_token=integrations_token, database_id=database_id)
+        self.database_id = database_id
+        self.request = Request(self.url, integrations_token=integrations_token)
 
-    def retrieve_page(self):
-        pass
+    def retrieve_page(self, page_id):
+        self.result = self.request.call_api_get(self.url + "/" + page_id)
 
     def create_page(self, properties=None, children=None):
         if children is None:
@@ -19,12 +20,15 @@ class Page:
         children = children
         body = {
             "parent": {
-                "database_id": self.request.NOTION_DATABASE_ID
+                "database_id": self.database_id
             },
             "properties": properties,
             "children": children
         }
-        self.result = self.request.call_api_post(body)
+        self.result = self.request.call_api_post(self.url, body)
 
-    def update_page(self):
-        pass
+    def update_page(self, page_id, properties):
+        body = {
+            "properties": properties,
+        }
+        self.result = self.request.call_api_patch(self.url + "/" + page_id, body)
