@@ -1,12 +1,12 @@
 import json
 
 import requests
+
 from notion_database import NOTION_VERSION
 
 
 class Request:
-    def __init__(self, url, integrations_token, database_id):
-        self.NOTION_DATABASE_ID = database_id
+    def __init__(self, url, integrations_token):
         self.NOTION_KEY = integrations_token
         self.NOTION_VERSION = NOTION_VERSION
         self.HEADER = {"Authorization": f"Bearer {self.NOTION_KEY}",
@@ -14,14 +14,14 @@ class Request:
                        "Notion-Version": self.NOTION_VERSION}
         self.url = url
 
-    def call_api_post(self, body):
-        r = requests.post(self.url, data=json.dumps(body), headers=self.HEADER).json()
+    def call_api_post(self, url, body):
+        r = requests.post(url, data=json.dumps(body), headers=self.HEADER).json()
         return r
 
     def call_api_get(self, url):
         r = requests.get(url, headers=self.HEADER).json()
         return r
 
-    def call_api_patch(self, body):
-        r = requests.patch(self.url, data=json.dumps(body), headers=self.HEADER).json()
+    def call_api_patch(self, url, body):
+        r = requests.patch(url, data=json.dumps(body), headers=self.HEADER).json()
         return r
